#!/bin/bash

USBDIR=/automnt/usb_stick/Update
FILENAME_CPU_UPDATE=WebserviceUpdate.tar
FILENAME_MEAS_CARD_UPDATE_MA10=MeasureCardUpdateMA10.mot
FILENAME_MEAS_CARD_UPDATE_MMU=MeasureCardUpdateMMU.mot
FILENAME_MEAS_CARD_UPDATE_RTA=MeasureCardUpdateRTA.mot
FILENAME_MD5SUM=Almemo500Update.md5sum
PATHNAME_MEAS_CARD_UPDATE=/tmp/

function get_update_flag {
	if test -d $USBDIR #USB - Stick vorhanden?
	then
	  res_value=0;
	  if test -f ${USBDIR}/${FILENAME_CPU_UPDATE} #Updatedatei CPU Karte vorhanden?
	  then
	  	res_value=$[res_value + 2]
	  fi
	  if [ -f ${USBDIR}/${FILENAME_MEAS_CARD_UPDATE_MA10} ] && [ -f ${USBDIR}/${FILENAME_MEAS_CARD_UPDATE_MMU} ] && [ -f ${USBDIR}/${FILENAME_MEAS_CARD_UPDATE_RTA} ] #Updatedatei(n)  Messkarte(n) vorhanden?
	  then
	  	res_value=$[res_value + 1]
	  fi
	  echo $res_value;
	else
	  echo 0;
	fi
}


# checks by parameter
if [[ $1 == "-content_info" ]]; then # liefert Flag zurueck welche Updatemodule enthalten in Update enthalten sind,
				     # 0x00: keine, 0x01: Messkarte, 0x02: CPU, 0x03: CPU und Messkarte
	result_info=$(get_update_flag);
	echo $result_info
	exit $result_info
elif [[ $1 == "-update" ]]; then
	if test -d $USBDIR #USB - Stick vorhanden?
	then
		result=$(get_update_flag)
		if [[ $result == 0 ]]; then
    			echo "ERR 2: no Update Files found"
    			exit 200
		elif [[ $result == 1 ]]; then # Update Messkarte

		    # Kopiere Update in /tmp/ Ordner
		    sudo cp ${USBDIR}/${FILENAME_MD5SUM} /tmp/
		    sudo cp ${USBDIR}/${FILENAME_MEAS_CARD_UPDATE_MA10} /tmp/
            sudo cp ${USBDIR}/${FILENAME_MEAS_CARD_UPDATE_MMU}  /tmp/
			sudo cp ${USBDIR}/${FILENAME_MEAS_CARD_UPDATE_RTA}  /tmp/
		    # Wechsle in /tmp/ Ordner
		    cd /tmp/
		    # Pruefe MD5 Checksumme der Datei und Speichere Resultat
		    MD5RESULT1=$(md5sum -c ${USBDIR}/${FILENAME_MD5SUM})
    		    echo ${MD5RESULT1}
		    if echo ${MD5RESULT1} | grep "${FILENAME_MEAS_CARD_UPDATE_MA10}: OK" | grep "${FILENAME_MEAS_CARD_UPDATE_MMU}: OK" | grep -q "${FILENAME_MEAS_CARD_UPDATE_RTA}: OK" #MD5 Pruefsumme(n) okay?
		    then
			# Wechsle in /tmp/ Ordner
			cd /tmp/
			# update Messkarte
			sudo /root/hexload ${PATHNAME_MEAS_CARD_UPDATE}
			HEXLOADRESULT=$?
			echo "Update Measure Card OK"
			exit $HEXLOADRESULT
		    else
		      echo "ERR 3: Update File damaged"
		      exit 300
		    fi

		elif [[ $result == 2 ]]; then # Update CPU

		    # Kopiere Update in /tmp/ Ordner
		    sudo cp ${USBDIR}/${FILENAME_MD5SUM} /tmp/
		    sudo cp ${USBDIR}/${FILENAME_CPU_UPDATE} /tmp/
		    # Wechsle in /tmp/ Ordner
		    cd /tmp/
		    # Pruefe MD5 Checksumme der Datei und Speichere Resultat
		    MD5RESULT1=$(md5sum -c ${USBDIR}/${FILENAME_MD5SUM})
    		    echo ${MD5RESULT1}
		    if echo ${MD5RESULT1} | grep -q "${FILENAME_CPU_UPDATE}: OK" #MD5 Pruefsumme okay?
		    then
			sudo tar -xf ${FILENAME_CPU_UPDATE} -C ../ #in Hauptverzeichnis extrahieren
			sync 
			echo "Update CPU OK"
			exit 0
		    else
		      echo "ERR 3: Update File damaged"
		      exit 300
		    fi

		elif [[ $result == 3 ]]; then # Update CPU + Messkarte

		    # Kopiere Update in /tmp/ Ordner
		    sudo cp ${USBDIR}/${FILENAME_MD5SUM} /tmp/
		    sudo cp ${USBDIR}/${FILENAME_MEAS_CARD_UPDATE_MA10} /tmp/
		    sudo cp ${USBDIR}/${FILENAME_MEAS_CARD_UPDATE_MMU} /tmp/
			sudo cp ${USBDIR}/${FILENAME_MEAS_CARD_UPDATE_RTA} /tmp/
		    sudo cp ${USBDIR}/${FILENAME_CPU_UPDATE} /tmp/
		    # Wechsle in /tmp/ Ordner
		    cd /tmp/
		    # Pruefe MD5 Checksumme der Datei und Speichere Resultat
		    MD5RESULT1=$(md5sum -c ${USBDIR}/${FILENAME_MD5SUM})
    		    echo ${MD5RESULT1}
		    if echo ${MD5RESULT1} | grep -q "${FILENAME_CPU_UPDATE}: OK" #MD5 Pruefsumme okay?
		    then
			# update CPU zuerst
			sudo tar -xf ${FILENAME_CPU_UPDATE} -C ../ #in Hauptverzeichnis extrahieren
			sync 
		    	if echo ${MD5RESULT1} | grep "${FILENAME_MEAS_CARD_UPDATE_MA10}: OK" | grep "${FILENAME_MEAS_CARD_UPDATE_MMU}: OK" | grep -q "${FILENAME_MEAS_CARD_UPDATE_RTA}: OK" #MD5 Pruefsumme(n) okay?
		    	then
				# update Messkarte
				sudo /root/hexload ${PATHNAME_MEAS_CARD_UPDATE}
				HEXLOADRESULT=$?
				echo "Update CPU and Measure Card OK"
				exit $HEXLOADRESULT
			else
		      		echo "ERR 3: Update File damaged"
		      		exit 300
			fi
		    else
		      echo "ERR 3: Update File damaged"
		      exit 300
		    fi
		else
 			echo "ERR 4: invalid Update"
 			exit 400
		fi
	else
 		echo "ERR 1: no USB device"
 		exit 100
	fi
else
	echo "MOEGLICHE PARAMETER:"
	echo "-content_info: liefert Flag zurueck welche Komponenten im Update enthalten sind,"
	echo "0x00: keine," 
	echo "0x01: Messkarte,"
	echo "0x02: CPU,"
	echo "0x03: CPU und Messkarte"
	echo "-update: Update aller gefundenen Komponenten wird gestartet"
	exit 
fi

